"""
    BasisTheory Vault API

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)  # noqa: E501

    The version of the OpenAPI document: v1
    Generated by: https://openapi-generator.tech
"""


import sys
import unittest

import basistheory
from basistheory.model.validation_problem_details import ValidationProblemDetails


class TestValidationProblemDetails(unittest.TestCase):
    """ValidationProblemDetails unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def testValidationProblemDetails(self):
        """Test ValidationProblemDetails"""
        # FIXME: construct object with mandatory attributes with example values
        # model = ValidationProblemDetails()  # noqa: E501
        pass


if __name__ == '__main__':
    unittest.main()
