"""
    BasisTheory Vault API

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)  # noqa: E501

    The version of the OpenAPI document: v1
    Generated by: https://openapi-generator.tech
"""


import sys
import unittest

import basistheory
from basistheory.model.application import Application
from basistheory.model.pagination import Pagination
globals()['Application'] = Application
globals()['Pagination'] = Pagination
from basistheory.model.application_paginated_list import ApplicationPaginatedList


class TestApplicationPaginatedList(unittest.TestCase):
    """ApplicationPaginatedList unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def testApplicationPaginatedList(self):
        """Test ApplicationPaginatedList"""
        # FIXME: construct object with mandatory attributes with example values
        # model = ApplicationPaginatedList()  # noqa: E501
        pass


if __name__ == '__main__':
    unittest.main()
