"""
    BasisTheory Vault API

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)  # noqa: E501

    The version of the OpenAPI document: v1
    Generated by: https://openapi-generator.tech
"""


import unittest

import basistheory
from basistheory.api.cards_api import CardsApi  # noqa: E501


class TestCardsApi(unittest.TestCase):
    """CardsApi unit test stubs"""

    def setUp(self):
        self.api = CardsApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_atomic_cards_create(self):
        """Test case for atomic_cards_create

        """
        pass


if __name__ == '__main__':
    unittest.main()
